#!/bin/sh

# Includes
. /var/log/copfilter/default/etc/global_settings
. /var/ipcop/main/settings
. /var/log/copfilter/default/langs/en.sh
. /var/log/copfilter/default/langs/${LANGUAGE}.sh

# define temporary files
TMP_FILE1=$TMPDIR/send_q_mail.tmp1.$$
TMP_FILE2=$TMPDIR/send_q_mail.tmp2.$$
TMP_FILE3=$TMPDIR/send_q_mail.tmp3.$$
TMP_FILE4=$TMPDIR/send_q_mail.tmp4.$$

cat /tmp/env_send_q_mail.tmp  |grep "\.spam=on$" |sed -e 's/=.*$//' >$TMP_FILE1
cat /tmp/env_send_q_mail.tmp  |grep "\.virus=on$" |sed -e 's/=.*$//' >>$TMP_FILE1
cat /tmp/env_send_q_mail.tmp  |grep "\.spam.whitelist=on$" |sed -e 's/=.*$//' >$TMP_FILE2
cat /tmp/env_send_q_mail.tmp  |grep "\.spam.delete=on$" |sed -e 's/=.*$//' >$TMP_FILE3
cat /tmp/env_send_q_mail.tmp  |grep "\.virus.delete=on$" |sed -e 's/=.*$//' >>$TMP_FILE3
cat /tmp/env_send_q_mail.tmp  |grep "DELETE_ALL" >>$TMP_FILE4

# Test if internet connection is active
if [ ! -f /var/ipcop/red/active ] ; then
   echo "no internet connection available, so no email will be sent" |logger -t "send_q_mail.sh $APPEND"
   exit
fi

exec 2>&1
CONF=/tmp/env_send_q_mail.tmp

# Check whether POP3 and/or SMTP domains have been set
if [ "x${SMTP_DOMAIN}" = "x" -a "x${POP3_DOMAIN}" = "x" ]; then
	echo "no valid Email domain for SMTP or POP3 is set, please enter it in the webgui, using domain from the Notification Email address in the meantime." |logger -t "send_q_mail.sh $APPEND"
    echo "<br>no valid Email domain for SMTP or POP3 is set, please enter it in the webgui. Using domain from the Notification Email address in the meantime." 
    if [ "x${EMAIL_ADR}" != "x" ]; then
		OURDOM=`echo $EMAIL_ADR | sed 's/.*@\(\.*\)/\1/'`
    else
        echo "no valid Email address for notifications is set in the webgui, exiting.." |logger -t "send_q_mail.sh $APPEND"
        echo "<br>no valid Email domain for SMTP or POP3 is set, nor an email address is set in the webui, exiting ... " 
        exit
    fi
else
	if [ "x${SMTP_DOMAIN}" != "x" -a "x${POP3_DOMAIN}" != "x" ]; then
		OURDOM=`echo $SMTP_DOMAIN,$POP3_DOMAIN | sed 's/\,/\|/g' | sed 's/\ //g'`
	else
		if [ "x${SMTP_DOMAIN}" != "x" ]; then
			OURDOM=`echo $SMTP_DOMAIN | sed 's/\,/\|/g' | sed 's/\ //g'`
		else
			OURDOM=`echo $POP3_DOMAIN | sed 's/\,/\|/g' | sed 's/\ //g'`
		fi
	fi
fi

# get ENV variables as:
#   IP and PORT of mailserver (here 95.0.0.100 : 25)
eval `/bin/egrep '^MAILSERVER|^DELETE_ALL_SPAM' $CONF`

# for pretty html viewing
echo "<pre>"

# send marked mails
SEARCH=`/bin/cat $CONF | /bin/grep 'spam=on'`
if [ ! "$SEARCH" = "" ]; then 
 for fsend in `/bin/grep 'spam=on' $CONF | /usr/bin/cut -d= -f1`; do
	# $fsend -- spam mail to resend
	
	# from: address
	FROM=`/bin/grep -m 1 '^From: ' "$fsend" | /bin/grep -E -o '[^<]*@[^>]*' | tr -d '\r'`

	# to: address
	# TO1 for :    <user@domain.com>                     : mail format
	TO1=`/bin/grep -m1 '^To: ' "$fsend" | /usr/bin/cut -d\  -f2- | /bin/grep -E -o '<[^<]*@[^>]*' | /usr/bin/tr -d '<"'"'" | tr -d '\r'`

	# TO2 for :    "user@domain.com" user@domain.com     : mail format
	TO2=`grep -m1 '^To: ' "$fsend" |  cut -d\  -f2 | /usr/bin/tr -d '<"'"'" | tr -d '\r'`

	# if TO1 is empty use TO2
	[ -n "$TO1" ] && TO="$TO1" || TO="$TO2"

	# cc: address
	# copy of TO: code block
	CC1=`/bin/grep -m1 '^To: ' "$fsend" | /usr/bin/cut -d\  -f2- | /bin/grep -E -o '<[^<]*@[^>]*' | /usr/bin/tr -d '<"'"'" | tr -d '\r'`
	CC2=`grep -m1 '^To: ' "$fsend" |  cut -d\  -f2 | /usr/bin/tr -d '<"'"'" | tr -d '\r'`
	[ -n "$CC1" ] && CC="$CC1" || CC="$TO2"

# ----	
	# check if in TO or CC found mail of our domain (here 'vartely.md')
	if echo "$TO" | /bin/egrep -i -q "$OURDOM"; then 
		ERRSTR="Address $TO is OK, resending..."
		echo "$ERRSTR"
		err=0
	elif echo "$CC" | /bin/egrep -i -q "$OURDOM"; then
		TO="$CC" 
		ERRSTR="Address $TO is bad for us, mail will send to $CC"
		echo "$ERRSTR"
		err=0
	else
		ERRSTR="Error: Address \"$TO\" or \"$CC\" not belong to our domain: $OURDOM , not resending"
		echo "$ERRSTR"
		err=1
	fi

	# if TO or CC address is valid then send email
	if [ -f $BASEDIR/etc/smtp_auth_enable ]; then
		[ $err -eq 0 ] && $SENDEMAIL -v -xu $SMTP_AUTH_USER -xp $SMTP_AUTH_PASS -f "$FROM" -s "${SMTP_HOST}" -t "$TO" -o message-file="$fsend" -o message-format=raw
	else
		[ $err -eq 0 ] && $SENDEMAIL -v -f "$FROM" -s "${SMTP_HOST}" -t "$TO" -o message-file="$fsend" -o message-format=raw
	fi

 done
fi

# send marked virus-mails
SEARCH=`/bin/cat $CONF | /bin/grep 'virus=on'`
if [ ! "$SEARCH" = "" ]; then 
 for fsend in `/bin/grep 'virus=on' $CONF | /usr/bin/cut -d= -f1`; do
	# $fsend -- spam mail to resend
	
	# from: address
	FROM=`/bin/grep -m 1 '^From: ' "$fsend" | /bin/grep -E -o '[^<]*@[^>]*' | tr -d '\r'`

	# to: address
	# TO1 for :    <user@domain.com>                     : mail format
	TO1=`/bin/grep -m1 '^To: ' "$fsend" | /usr/bin/cut -d\  -f2- | /bin/grep -E -o '<[^<]*@[^>]*' | /usr/bin/tr -d '<"'"'" | tr -d '\r'`

	# TO2 for :    "user@domain.com" user@domain.com     : mail format
	TO2=`grep -m1 '^To: ' "$fsend" |  cut -d\  -f2 | /usr/bin/tr -d '<"'"'" | tr -d '\r'`

	# if TO1 is empty use TO2
	[ -n "$TO1" ] && TO="$TO1" || TO="$TO2"

	# cc: address
	# copy of TO: code block
	CC1=`/bin/grep -m1 '^To: ' "$fsend" | /usr/bin/cut -d\  -f2- | /bin/grep -E -o '<[^<]*@[^>]*' | /usr/bin/tr -d '<"'"'" | tr -d '\r'`
	CC2=`grep -m1 '^To: ' "$fsend" |  cut -d\  -f2 | /usr/bin/tr -d '<"'"'" | tr -d '\r'`
	[ -n "$CC1" ] && CC="$CC1" || CC="$TO2"

# ----	
	# check if in TO or CC found mail of our domain (here 'vartely.md')
	if echo "$TO" | /bin/egrep -i -q "$OURDOM"; then 
		ERRSTR="Address $TO is OK, resending..."
		echo "$ERRSTR"
		err=0
	elif echo "$CC" | /bin/egrep -i -q "$OURDOM"; then
		TO="$CC" 
		ERRSTR="Address $TO is bad for us, mail will send to $CC"
		echo "$ERRSTR"
		err=0
	else
		ERRSTR="Error: Address \"$TO\" or \"$CC\" not belong to our domain: $OURDOM , not resending"
		echo "$ERRSTR"
		err=1
	fi

	# if TO or CC address is valid then send email
	if [ -f $BASEDIR/etc/smtp_auth_enable ]; then
		[ $err -eq 0 ] && $SENDEMAIL -v -xu $SMTP_AUTH_USER -xp $SMTP_AUTH_PASS -f "$FROM" -s "${SMTP_HOST}" -t "$TO" -o message-file="$fsend" -o message-format=raw
	else
		[ $err -eq 0 ] && $SENDEMAIL -v -f "$FROM" -s "${SMTP_HOST}" -t "$TO" -o message-file="$fsend" -o message-format=raw
	fi

 done
fi


for i in `cat $TMP_FILE2`
do

    ii=`echo $i | sed -e 's/.whitelist//'` 

    SENDER2=`cat $ii |sed -n '1,/^$/p' | $BASEDIR/opt/tools/bin/formail -b -f -c | /usr/bin/awk -f $BASEDIR/opt/tools/bin/extract_email_adresses_from.awk`
    SENDER=`echo $SENDER2| sed -e 'y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/'`

    #echo "NEXT <br />"
    #echo "SE $SENDER <br />"
    #echo "REC $RECIPIENTS <br />"
    #echo "SUB $MAILSUBJECT <br />"

     for h in $SENDER
       do
       grep -i "whitelist_from $h" $BASEDIR/etc/cp_spam_whitelist/local_webgui.cf &>/dev/null
       RESULT=$?
       if [  "x${RESULT}" != "x0" ];then
            echo "whitelist_from $h" >/tmp/add_to_list.tmp
            /usr/local/bin/copfilter_add_to_list
            echo "<br /> $CP_send_qmail_whitelist_add &nbsp; ${h}"
        #/tmp/add_to_list.tmp
        #/tmp/remove_from_list.tmp
       else
            echo "<br />$CP_send_qmail_whitelist_add2 &nbsp; ${h}"
       fi
     done


done

echo "<br />"
echo "<br />"
echo "<br />"
echo "<br />"
echo "<b><u>${CP_q_delete}</b></u>"



for i in `cat $TMP_FILE3`
do
    ii=`echo $i  |sed -e "s/.delete$//"`
    iii=`echo $i |sed -e "s/.*\/\(.*\)/\1/" -e "s/.spam.delete//" -e "s/.virus.delete//"`
    if [ "x${ii}" != "x" ];then
        echo "<br />$CP_send_qmail_del  $iii"
        rm -f ${ii}*
        if [ -f ${BASEDIR}/opt/p3scan/tmp/${iii} ]; then
    	    rm -f ${BASEDIR}/opt/p3scan/tmp/${iii}
    	    echo "<br />Tmpfile $CP_send_qmail_del  $iii"
    	fi
    	if [ -f ${BASEDIR}/opt/proxsmtp/tmp/${iii} ]; then
    	    rm -f ${BASEDIR}/opt/proxsmtp/tmp/${iii}
    	    echo "<br />Tmpfile $CP_send_qmail_del  $iii"
    	fi
    fi 
done


echo "<br />"
echo "<br />"
echo "<br />"
echo "<br />"
echo "<b><u>${CP_q_delete_all}</b></u>"
echo "<br />"

grep "DELETE_ALL_SPAM=on" $TMP_FILE4 &>/dev/null
RESULT1=$?
echo $RESULT
grep "DELETE_ALL_VIRUS=on" $TMP_FILE4 &>/dev/null
RESULT2=$?
echo $RESULT
if [ "x${RESULT1}" = "x0" ]; then
     find $BASEDIR/opt/p3scan/quarantine/ -name *.spam* -exec rm \{\} \;
     find $BASEDIR/opt/proxsmtp/quarantine/ -name *.spam* -exec rm \{\} \;
     echo DONE
fi

if [ "x${RESULT2}" = "x0" ]; then
     find $BASEDIR/opt/p3scan/quarantine/ -name *.virus* -exec rm \{\} \;
     find $BASEDIR/opt/proxsmtp/quarantine/ -name *.virus* -exec rm \{\} \;
     echo DONE
fi


echo "<br />"
echo "<br />"


#echo "=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-" > $TMP_FILE2
#echo >> $TMP_FILE2


echo "</pre>"
 
#cleanup
rm -f $TMP_FILE1
rm -f $TMP_FILE2
rm -f $TMP_FILE3
rm -f $TMP_FILE4
#rm -f /tmp/env_send_q_mail.tmp
